@@ -9,7 +9,6 @@
 #  http://lists.partiwm.org/pipermail/parti-discuss/2008-September/000042.html
 # (also do not import anything that imports gtk)
 import gobject
-import glib
 import subprocess
 import sys
 import os.path
@@ -200,7 +199,7 @@ fi
 """)
     return "".join(script)
 
-def write_runner_shell_script(dotxpra, contents):
+def write_runner_shell_script(dotxpra, contents, overwrite=True):
     # This used to be given a display-specific name, but now we give it a
     # single fixed name and if multiple servers are started then the last one
     # will clobber the rest.  This isn't great, but the tradeoff is that it
@@ -210,6 +209,8 @@ def write_runner_shell_script(dotxpra, contents):
     # people run into problems or autodiscovery turns out to be less useful
     # than expected.
     scriptpath = os.path.join(dotxpra.confdir(), "run-xpra")
+    if os.path.exists(scriptpath) and not overwrite:
+        return
     # Write out a shell-script so that we can start our proxy in a clean
     # environment:
     scriptfile = open(scriptpath, "w")
@@ -518,6 +519,7 @@ def verify_display_ready(xvfb, display_name, shadowing):
     assert "gtk" not in sys.modules
     import gtk.gdk          #@Reimport
     try:
+        import glib
         glib.threads_init()
     except:
         #old versions do not have this method
