@@ -378,9 +378,6 @@ class WindowSource(object):
         info[prefix+"property.fullscreen"+suffix] = self.fullscreen or False
         self.statistics.add_stats(info, prefix, suffix)
 
-        #batch delay stats:
-        self.batch_config.add_stats(info, "", suffix)
-
         #speed / quality properties (not necessarily the same as the video encoder settings..):
         info[prefix+"property.min_speed"+suffix] = self._fixed_min_speed
         info[prefix+"property.speed"+suffix] = self._fixed_speed
@@ -600,7 +597,7 @@ class WindowSource(object):
         self.expire_timer = self.timeout_add(int(delay), self.expire_delayed_region, delay)
 
     def must_batch(self, delay):
-        return FORCE_BATCH or self.batch_config.always or delay<self.batch_config.min_delay
+        return FORCE_BATCH or self.batch_config.always or delay>self.batch_config.min_delay
 
 
     def expire_delayed_region(self, delay):
@@ -1013,15 +1010,12 @@ class WindowSource(object):
             refreshlog("auto refresh: was a high quality %s screen update, ignoring", encoding)
             #lossless already: small region sent lossless or encoding is already lossless
             #it is safe to call this method on window because it does not call down to X11:
-            if self.refresh_timer and ww*wh>=w*h*9/10:
+            if self.refresh_timer and w*h>=ww*wh*90/100:
                 #discard pending auto-refresh since this update covered more than 90% of the window
                 self.cancel_refresh_timer()
             #don't change anything: if we have a timer, keep it
             return
-        if self._damage_delayed is not None:
-            #more updates coming already
-            return
-        if self.refresh_timer and w*h<ww*wh/20:
+        if self.refresh_timer and w*h<ww*wh*20/100:
             #a refresh is already due, and this update is small (20%), don't change anything
             return
         #if we're here: the window is still valid and this was a lossy update,
@@ -1042,9 +1036,6 @@ class WindowSource(object):
         if not window.is_managed():
             #window is gone
             return
-        if self._damage_delayed:
-            #new incoming damage
-            return
         if not self.auto_refresh_encodings or self.is_cancelled():
             #can happen during cleanup
             return
@@ -1132,7 +1123,11 @@ class WindowSource(object):
         if decode_time:
             start_send_at, start_bytes, end_send_at, end_bytes, pixels = pending
             bytecount = end_bytes-start_bytes
-            self.global_statistics.record_latency(self.wid, decode_time, start_send_at, end_send_at, pixels, bytecount)
+            #it is possible, though very unlikely,
+            #that we get the ack before we've had a chance to call
+            #damage_packet_sent, so we must validate the data:
+            if bytecount>0 and end_send_at>0:
+                self.global_statistics.record_latency(self.wid, decode_time, start_send_at, end_send_at, pixels, bytecount)
         else:
             #something failed client-side, so we can't rely on the delta being available
             self.last_pixmap_data = None
